@@ -26,8 +26,8 @@
 /* #undef HAVE_ASM_TERMBITS_H */
 #define HAVE_BSEARCH 1
 #define HAVE_CRYPT_H 1
-/* #undef HAVE_CURSES_H */
-/* #undef HAVE_CXXABI_H */
+#define HAVE_CURSES_H 1
+/* #undef HAVE_BFD_H */
 /* #undef HAVE_NCURSES_H */
 /* #undef HAVE_NDIR_H */
 #define HAVE_DIRENT_H 1
@@ -40,11 +40,13 @@
 #define HAVE_FNMATCH_H 1
 /* #undef HAVE_FPU_CONTROL_H */
 #define HAVE_GRP_H 1
-#define HAVE_EXPLICIT_TEMPLATE_INSTANTIATION 1
 /* #undef HAVE_IA64INTRIN_H */
 #define HAVE_IEEEFP_H 1
 #define HAVE_INTTYPES_H 1
+/* #undef HAVE_KQUEUE */
 #define HAVE_LIMITS_H 1
+/* #undef HAVE_LINK_H */
+/* #undef HAVE_LINUX_UNISTD_H */
 #define HAVE_LOCALE_H 1
 #define HAVE_MALLOC_H 1
 #define HAVE_MEMORY_H 1
@@ -81,15 +83,20 @@
 #define HAVE_SYS_SELECT_H 1
 #define HAVE_SYS_SHM_H 1
 #define HAVE_SYS_SOCKET_H 1
+/* #undef HAVE_SYS_SOCKIO_H */
+#define HAVE_SYS_UTSNAME_H 1
 #define HAVE_SYS_STAT_H 1
 /* #undef HAVE_SYS_STREAM_H */
+/* #undef HAVE_SYS_SYSCALL_H */
 /* #undef HAVE_SYS_TERMCAP_H */
-#define HAVE_SYS_TIMEB_H 1
+/* #undef HAVE_SYS_TIMEB_H */
 #define HAVE_SYS_TIMES_H 1
 #define HAVE_SYS_TIME_H 1
 #define HAVE_SYS_TYPES_H 1
 #define HAVE_SYS_UN_H 1
 /* #undef HAVE_SYS_VADVISE_H */
+#define HAVE_SYS_STATVFS_H 1
+#define HAVE_UCONTEXT_H 1
 #define HAVE_TERM_H 1
 /* #undef HAVE_TERMBITS_H */
 #define HAVE_TERMIOS_H 1
@@ -105,22 +112,23 @@
 #define HAVE_SYS_PARAM_H 1
 
 /* Libraries */
-/* #undef HAVE_LIBPTHREAD */
+#define HAVE_LIBPTHREAD 1
 /* #undef HAVE_LIBM */
-/* #undef HAVE_LIBDL */
-/* #undef HAVE_LIBRT */
+#define HAVE_LIBDL 1
+#define HAVE_LIBRT 1
 /* #undef HAVE_LIBSOCKET */
 /* #undef HAVE_LIBNSL */
 #define HAVE_LIBCRYPT 1
 /* #undef HAVE_LIBMTMALLOC */
 #define HAVE_LIBWRAP 1
+/* #undef HAVE_SYSTEMD */
 /* Does "struct timespec" have a "sec" and "nsec" field? */
 /* #undef HAVE_TIMESPEC_TS_SEC */
 
 /* Readline */
-/* #undef HAVE_HIST_ENTRY */
-/* #undef USE_LIBEDIT_INTERFACE */
-#define USE_NEW_READLINE_INTERFACE 1
+#define HAVE_HIST_ENTRY 1
+#define USE_LIBEDIT_INTERFACE 1
+/* #undef USE_NEW_READLINE_INTERFACE */
 
 /* #undef FIONREAD_IN_SYS_IOCTL */
 #define GWINSZ_IN_SYS_IOCTL 1
@@ -128,6 +136,7 @@
 /* #undef FIONREAD_IN_SYS_FILIO */
 
 /* Functions we may want to use. */
+#define HAVE_ACCESS 1
 /* #undef HAVE_AIOWAIT */
 #define HAVE_ALARM 1
 #define HAVE_ALLOCA 1
@@ -148,6 +157,8 @@
 #define HAVE_FCNTL 1
 /* #undef HAVE_FCONVERT */
 #define HAVE_FDATASYNC 1
+#define HAVE_DECL_FDATASYNC 1
+#define HAVE_FEDISABLEEXCEPT 1
 #define HAVE_FESETROUND 1
 #define HAVE_FINITE 1
 #define HAVE_FP_EXCEPT 1
@@ -156,6 +167,7 @@
 #define HAVE_FSYNC 1
 #define HAVE_FTIME 1
 #define HAVE_GETADDRINFO 1
+#define HAVE_GETIFADDRS 1
 #define HAVE_GETCWD 1
 /* #undef HAVE_GETHOSTBYADDR_R */
 /* #undef HAVE_GETHRTIME */
@@ -172,6 +184,7 @@
 #define HAVE_GETWD 1
 #define HAVE_GMTIME_R 1
 /* #undef gmtime_r */
+#define HAVE_IN_ADDR_T 1
 #define HAVE_INITGROUPS 1
 #define HAVE_ISSETUGID 1
 #define HAVE_GETUID 1
@@ -206,12 +219,17 @@
 #define HAVE_POLL 1
 /* #undef HAVE_PORT_CREATE */
 #define HAVE_POSIX_FALLOCATE 1
+/* #undef HAVE_LINUX_FALLOC_H */
+/* #undef HAVE_FALLOCATE */
+/* #undef HAVE_FALLOC_PUNCH_HOLE_AND_KEEP_SIZE */
 #define HAVE_PREAD 1
 #define HAVE_PAUSE_INSTRUCTION 1
 /* #undef HAVE_FAKE_PAUSE_INSTRUCTION */
+/* #undef HAVE_HMT_PRIORITY_INSTRUCTION */
 /* #undef HAVE_RDTSCLL */
 /* #undef HAVE_READ_REAL_TIME */
 /* #undef HAVE_PTHREAD_ATTR_CREATE */
+#define HAVE_PTHREAD_ATTR_GETGUARDSIZE 1
 #define HAVE_PTHREAD_ATTR_GETSTACKSIZE 1
 /* #undef HAVE_PTHREAD_ATTR_SETPRIO */
 /* #undef HAVE_PTHREAD_ATTR_SETSCHEDPARAM */
@@ -228,7 +246,7 @@
 #define HAVE_PTHREAD_SIGMASK 1
 /* #undef HAVE_PTHREAD_THREADMASK */
 /* #undef HAVE_PTHREAD_YIELD_NP */
-#define HAVE_PTHREAD_YIELD_ZERO_ARG 1
+/* #undef HAVE_PTHREAD_YIELD_ZERO_ARG */
 #define PTHREAD_ONCE_INITIALIZER PTHREAD_ONCE_INIT
 #define HAVE_PUTENV 1
 /* #undef HAVE_RE_COMP */
@@ -244,6 +262,7 @@
 /* #undef HAVE_SETFD */
 #define HAVE_SETENV 1
 #define HAVE_SETLOCALE 1
+#define HAVE_SETUPTERM 1
 #define HAVE_SIGADDSET 1
 #define HAVE_SIGEMPTYSET 1
 #define HAVE_SIGHOLD 1
@@ -263,7 +282,7 @@
 /* #undef HAVE_FGETLN */
 #define HAVE_STRNLEN 1
 #define HAVE_STRPBRK 1
-#define HAVE_STRSEP 1
+/* #undef HAVE_STRSEP */
 #define HAVE_STRSTR 1
 #define HAVE_STRTOK_R 1
 #define HAVE_STRTOL 1
@@ -281,6 +300,7 @@
 #define HAVE_TIME 1
 #define HAVE_TIMES 1
 #define HAVE_VALLOC 1
+#define HAVE_VIDATTR 1
 #define HAVE_VIO_READ_BUFF 1
 #define HAVE_VASPRINTF 1
 #define HAVE_VPRINTF 1
@@ -306,13 +326,19 @@
 /* #undef HAVE_TIMESPEC_TS_SEC */
 #define STRUCT_DIRENT_HAS_D_INO 1
 /* #undef STRUCT_DIRENT_HAS_D_NAMLEN */
+#define STRUCT_TIMESPEC_HAS_TV_SEC 1
+#define STRUCT_TIMESPEC_HAS_TV_NSEC 1
 #define SPRINTF_RETURNS_INT 1
 
 #define USE_MB 1
 #define USE_MB_IDENT 1
 
+/* this means that valgrind headers and macros are available */
 /* #undef HAVE_VALGRIND */
 
+/* this means WITH_VALGRIND - we change some code paths for valgrind */
+/* #undef HAVE_valgrind */
+
 /* Types we may use */
 #ifdef __APPLE__
   /*
@@ -379,9 +405,9 @@
 
 #define SOCKET_SIZE_TYPE socklen_t
 
-#define HAVE_MBSTATE_T
+#define HAVE_MBSTATE_T 1
 
-#define MAX_INDEXES 64
+#define MAX_INDEXES 64U
 
 #define QSORT_TYPE_IS_VOID 1
 #define RETQSORTTYPE void
@@ -389,6 +415,7 @@
 #define SIGNAL_RETURN_TYPE_IS_VOID 1
 #define RETSIGTYPE void
 #define VOID_SIGHANDLER 1
+/* #undef HAVE_SIGHANDLER_T */
 #define STRUCT_RLIMIT struct rlimit
 
 #ifdef __APPLE__
@@ -414,15 +441,15 @@
 #define HAVE_WCTYPE_H 1
 #define HAVE_WCHAR_H 1
 #define HAVE_LANGINFO_H 1
-#define HAVE_MBRLEN
+#define HAVE_MBRLEN 1
 /* #undef HAVE_MBSCMP */
-#define HAVE_MBSRTOWCS
-#define HAVE_WCRTOMB
-#define HAVE_MBRTOWC
-#define HAVE_WCSCOLL
-#define HAVE_WCSDUP
-#define HAVE_WCWIDTH
-#define HAVE_WCTYPE
+#define HAVE_MBSRTOWCS 1
+#define HAVE_WCRTOMB 1
+#define HAVE_MBRTOWC 1
+#define HAVE_WCSCOLL 1
+#define HAVE_WCSDUP 1
+#define HAVE_WCWIDTH 1
+#define HAVE_WCTYPE 1
 #define HAVE_ISWLOWER 1
 #define HAVE_ISWUPPER 1
 #define HAVE_TOWLOWER 1
@@ -436,25 +463,25 @@
 #define HAVE_STRCASECMP 1
 #define HAVE_STRNCASECMP 1
 #define HAVE_STRDUP 1
-#define HAVE_LANGINFO_CODESET 
+#define HAVE_LANGINFO_CODESET  1
 #define HAVE_TCGETATTR 1
 #define HAVE_FLOCKFILE 1
 
 #define HAVE_WEAK_SYMBOL 1
-/* #undef HAVE_ABI_CXA_DEMANGLE */
-
+#define HAVE_ABI_CXA_DEMANGLE 1
+#define HAVE_ATTRIBUTE_CLEANUP 1
 
 #define HAVE_POSIX_SIGNALS 1
 /* #undef HAVE_BSD_SIGNALS */
 /* #undef HAVE_SVR3_SIGNALS */
 /* #undef HAVE_V7_SIGNALS */
-
+#define HAVE_ERR_remove_thread_state 1
 
 /* #undef HAVE_SOLARIS_STYLE_GETHOST */
 
 /* #undef MY_ATOMIC_MODE_DUMMY */
-/* #undef MY_ATOMIC_MODE_RWLOCKS */
 #define HAVE_GCC_ATOMIC_BUILTINS 1
+#define HAVE_GCC_C11_ATOMICS 1
 /* #undef HAVE_SOLARIS_ATOMIC */
 /* #undef HAVE_DECL_SHM_HUGETLB */
 /* #undef HAVE_LARGE_PAGES */
@@ -465,7 +492,6 @@
 /* #undef _LARGE_FILES */
 #define _LARGEFILE_SOURCE 1
 /* #undef _LARGEFILE64_SOURCE */
-/* #undef _FILE_OFFSET_BITS */
 
 #define TIME_WITH_SYS_TIME 1
 
@@ -473,6 +499,7 @@
 
 #define SYSTEM_TYPE "CYGWIN"
 #define MACHINE_TYPE "i686"
+#define DEFAULT_MACHINE "i686"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -498,13 +525,20 @@
 /* #undef strtoll */
 /* #undef strtoull */
 /* #undef vsnprintf */
+#if (_MSC_VER > 1800)
+#define tzname _tzname
+#define P_tmpdir "C:\\TEMP"
+#endif
 #if (_MSC_VER > 1310)
 # define HAVE_SETENV
 #define setenv(a,b,c) _putenv_s(a,b)
 #endif
+#define PSAPI_VERSION 1     /* for GetProcessMemoryInfo() */
 
-
-
+/* We don't want the min/max macros */
+#ifdef __WIN__
+#define NOMINMAX 1
+#endif
 
 /*
   MySQL features
@@ -512,7 +546,6 @@
 /* #undef ENABLED_LOCAL_INFILE */
 #define ENABLED_PROFILING 1
 /* #undef EXTRA_DEBUG */
-/* #undef BACKUP_TEST */
 /* #undef CYBOZU */
 /* #undef USE_SYMDIR */
 
@@ -568,7 +601,8 @@
 #define HAVE_CHARSET_utf32 1
 #define HAVE_UCA_COLLATIONS 1
 #define HAVE_COMPRESS 1
-
+#define HAVE_EncryptAes128Ctr 1
+#define HAVE_EncryptAes128Gcm 1
 
 /*
   Stuff that always need to be defined (compile breaks without it)
@@ -585,41 +619,58 @@
 #define WITH_MYISAM_STORAGE_ENGINE 1
 #define WITH_MYISAMMRG_STORAGE_ENGINE 1
 #define WITH_HEAP_STORAGE_ENGINE 1
+/* #undef WITH_INNOBASE_STORAGE_ENGINE */
+#define WITH_XTRADB_STORAGE_ENGINE 1
 #define WITH_CSV_STORAGE_ENGINE 1
 #define WITH_PARTITION_STORAGE_ENGINE 1
 #define WITH_PERFSCHEMA_STORAGE_ENGINE 1
-/* #undef WITH_NDBCLUSTER_STORAGE_ENGINE */
-#if (WITH_NDBCLUSTER_STORAGE_ENGINE) && !defined(EMBEDDED_LIBRARY)
-# define HAVE_NDB_BINLOG 1
-#endif
+#define WITH_ARIA_STORAGE_ENGINE 1
+#define USE_ARIA_FOR_TMP_TABLES 1
 
 #define DEFAULT_MYSQL_HOME "/usr"
 #define SHAREDIR "/usr/share/mysql"
 #define DEFAULT_BASEDIR "/usr"
 #define MYSQL_DATADIR "/var/lib/mysql"
 #define DEFAULT_CHARSET_HOME "/usr"
-#define PLUGINDIR "/usr/lib/mysql/plugins"
-#define DEFAULT_SYSCONFDIR "/usr/etc"
-#define DEFAULT_TMPDIR P_tmpdir
+#define PLUGINDIR "/usr/lib/mysql/plugin"
+#define DEFAULT_SYSCONFDIR "/etc"
+#define DEFAULT_TMPDIR "/var/tmp"
 
 /* #undef SO_EXT */
 
-#define MYSQL_MAJOR_VERSION 5
-#define MYSQL_MINOR_VERSION 5
+#define MYSQL_VERSION_MAJOR 10
+#define MYSQL_VERSION_MINOR 1
+#define MYSQL_VERSION_PATCH 26
+#define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 5.5.45"
+#define PACKAGE_STRING "MySQL Server 10.1.26"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "5.5.45"
-#define VERSION "5.5.45"
+#define PACKAGE_VERSION "10.1.26"
+#define VERSION "10.1.26"
 #define PROTOCOL_VERSION 10
 
+#define MALLOC_LIBRARY "system"
 
 /* time_t related defines */
 
 #define SIZEOF_TIME_T 4
 /* #undef TIME_T_UNSIGNED */
 
+#ifndef EMBEDDED_LIBRARY
+/* #undef WSREP_INTERFACE_VERSION */
+#define WITH_WSREP 1
+#define WSREP_PROC_INFO 1
+#endif
+
+#ifdef _AIX
+/*
+  AIX includes inttypes.h from sys/types.h
+  Explicitly request format macros before the first inclusion of inttypes.h
+*/
+#define __STDC_FORMAT_MACROS
+#endif
+
 #endif
