@@ -11,17 +11,22 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MYSQL_SERVER_VERSION		"5.5.45"
-#define MYSQL_BASE_VERSION		"mysqld-5.5"
+#define MYSQL_SERVER_VERSION		"10.1.26-MariaDB"
+#define MYSQL_BASE_VERSION		"mysqld-10.1"
+#define MARIADB_BASE_VERSION		"mariadb-10.1"
 #define MYSQL_SERVER_SUFFIX_DEF		""
 #define FRM_VER				6
-#define MYSQL_VERSION_ID		50545
+#define MYSQL_VERSION_ID		100126
 #define MYSQL_PORT			3306
 #define MYSQL_PORT_DEFAULT		0
 #define MYSQL_UNIX_ADDR			"/var/run/mysql.sock"
 #define MYSQL_CONFIG_NAME		"my"
 #define MYSQL_COMPILATION_COMMENT	"Source distribution"
 
+#ifdef WITH_WSREP
+#define WSREP_PATCH_VERSION             "wsrep_25.19"
+#endif
+
 /* mysqld compile time options */
 #endif /* _CUSTOMCONFIG_ */
 
